/*
This program is confidential and proprietary to MRJ Technology Solutions
and may not be reproduced, published or disclosed to others without
written authorization from MRJ.

Copyright (c) 1998 MRJ Technology Solutions, Inc. All Rights Reserved.

This program is derived from prior work some of which was originally
written as a joint project between the Numerical Aerospace Simulation
(NAS) Systems Division of NASA Ames Research Center and the National 
Energy Research Supercomputer Center (NERSC) of Lawrence Livermore   
National Laboratory.
*/


#ifndef TRACEJOB_H
#define TRACEJOB_H

/* Symbolic constants */

/* default number of columns on a terminal */
#ifndef DEFAULT_WRAP
#define DEFAULT_WRAP 80
#endif

/*
 * filter excessive log entires
 */
#ifndef FILTER_EXCESSIVE
#define FILTER_EXCESSIVE
#endif

/* if filter excessive if turned on and there are at least this many 
 * log entires, its considered is considered excessive
 */
#ifndef EXCESSIVE_COUNT 
#define EXCESSIVE_COUNT 15
#endif
 
/* number of entries to start */
#ifndef DEFAULT_LOG_LINES
#define DEFAULT_LOG_LINES 1024
#endif
 
#define SECONDS_IN_DAY 86400
 
/* indicies into the mid_path array */
enum index
{
  IND_ACCT = 0,
  IND_SERVER = 1,
  IND_MOM = 2,
  IND_SCHED = 3
};
 
/* fields of a log entry */
enum field
{
  FLD_DATE = 0,
  FLD_EVENT = 1,
  FLD_OBJ = 2,
  FLD_TYPE = 3,
  FLD_NAME = 4,
  FLD_MSG = 5
};

/* A PBS log entry */
struct log_entry
{
  char *date;           /* date of log entry */
  time_t date_time;     /* number of seconds from the epoch to date */
  char *event;          /* event type */
  char *obj;            /* what entity is writing the log */
  char *type;           /* type of object Job/Svr/etc */
  char *name;           /* name of object */
  char *msg;            /* log message */
  char log_file;        /* What log file */
  int lineno;		/* what line in the file.  used to stabilize the sort */
  unsigned no_print:1;	/* whether or not to print the message */
  /* A=accounting S=server M=Mom L=Scheduler */
};
 
/* prototypes */
int sort_by_date( const void *v1, const void *v2 );
void parse_log(FILE *fp, char *job, int act);
char *strip_path( char *path );
void free_log_entry( struct log_entry *lg );
void line_wrap(char *line, int start, int end);
char *log_path( char *path, int index, struct tm *tm_ptr );
void alloc_more_space();
void filter_excess( int threshold );
int sort_by_message( const void *v1, const void *v2 );


/* used by getopt(3) */
extern char *optarg;
extern int optind;

#endif
